@@ -77,6 +77,7 @@ Knapster::Knapster(const char *name)
   kapp->getConfig()->setDollarExpansion(false);
 #endif
 
+
   Preferences p=PropertiesDlg::readPrefs();
   setCaption(name);
 
@@ -119,6 +120,15 @@ Knapster::Knapster(const char *name)
 
   writeConsole("KNapster " VERSION " - John Donoghue, 2000\ndonoghue@chariot.net.au\n");
 
+  // set up the past history
+  QStrList list(true);
+#ifdef KDE2
+  config->->readListEntry ("history",list);
+#else
+  kapp->getConfig()->readListEntry ("history",list);
+#endif
+  searchpanel->setSearchHistory(list);
+
 }
 
 Knapster::~Knapster()
@@ -142,6 +152,16 @@ void Knapster::closeDown()
       player.kill();
       return;
     }
+
+    // save the past search history
+    QStrList str = searchpanel->getSearchHistory();
+#ifdef KDE2
+    config->writeEntry("history",str);
+#else
+    kapp->getConfig()->writeEntry("history",str);
+#endif
+
+
 #ifdef KDE2
     config->writeEntry("winw",width());
     config->writeEntry("winh",height());
@@ -194,10 +214,10 @@ void Knapster::setupTabs()
   tab->addTab(downloadpanel,i18n("Downloads"));
 
   // tab4 - uploads  ---------------------------
-  //QWidget *frame=new QWidget(tab);
   uploadpanel=new UploadPanel(tab);
   connect(uploadpanel,SIGNAL(ping(const char *)),this,SLOT(addPingItem(const char *)));
   connect(uploadpanel,SIGNAL(whois(const char *)),this,SLOT(sendWhois(const char *)));
+  connect(uploadpanel,SIGNAL(terminate(QListViewItem *)),this,SLOT(uploadTerminate(QListViewItem *)));
   tab->addTab(uploadpanel,i18n("Uploads"));
 
   // tab5 - local mp3 --------------------------
@@ -221,10 +241,12 @@ void Knapster::setupMenus()
   menuBar()->enableMoving(false);
 #endif /* KDE2 */
 
-  // Project
+  // COnnect
   QPopupMenu *m=new QPopupMenu();
   m->insertItem(i18n("&LogOn/Off"),this,SLOT(menuLogon()));
   m->insertItem(i18n("&Relogin"),this,SLOT(menuRelogon()));
+//    m->insertSeparator();
+//  m->insertItem(i18n("&Connect to recent"),this,SLOT(menuRecent()));
     m->insertSeparator();
   m->insertItem(i18n("E&xit"),this,SLOT(closeDown()));
 
@@ -676,7 +698,27 @@ void Knapster::downloadTerminate(QListViewItem *it)
   }
 }
 
-// slot for downlaod popupmenu terminate item
+// slot for uplaod terminate item signal
+void Knapster::uploadTerminate(QListViewItem *it)
+{
+  if(it) {
+#ifdef DEBUG_1
+    cerr<<"trying to kill upload "<<it->text(0)<<endl<<flush;
+#endif
+    SongInfo *sg;
+    // find it
+    for(sg=uploadlist.first();sg!=NULL;sg=uploadlist.next()) {
+      if(sg->md5.findRev(it->text(6))==0) {
+         // found match
+         if(sg->dload) {
+             sg->dload->cancel();
+         }
+         break;
+      }
+    }
+  }
+}
+
 
 void Knapster::playsong(const char *name)
 {
@@ -703,13 +745,16 @@ void Knapster::playsong(const char *name)
       player << (const char *)cmdarg;
       cmdarg = extractString(tmp);
     }
+#ifdef DEBUG_1
     cerr<<"start play!!\n"<<flush;
+#endif
     if(!player.start( /*KProcess::DontCare*/ /*,KProcess::AllOutput*/))
          cout<<"error running mp3player!!!\n"<<flush;
   }
   return;
 }
 
+
 void Knapster::playsong_dl(const char *name)
 {
   Preferences p=PropertiesDlg::readPrefs();
@@ -752,7 +797,9 @@ void Knapster::playsong_dl(const char *name)
       player << (const char *)cmdarg;
       cmdarg = extractString(tmp);
     }
+#ifdef DEBUG_1
     cerr<<"start play!!\n"<<flush;
+#endif
     if(!player.start( /*KProcess::DontCare*/ /*,KProcess::AllOutput*/))
          cout<<"error running mp3player!!!\n"<<flush;
   }
@@ -827,6 +874,12 @@ void Knapster::addDownloadItem(SongInfo *tmpinfo)
        writeConsole(tmpstr.data());
        return;
      }
+     else if(p.port==0) {
+       writeConsole(QString(i18n("** Can't download "))
+          + tmpinfo->filename
+          + i18n(" since both persons are behind a firewall"));
+       return;
+     }
 
   }
 
@@ -929,7 +982,8 @@ void Knapster::updateDownloadList()
       if(sg->status==NapsterDownload::DL_FINISHED) {
         if((PropertiesDlg::readPrefs()).beep) kapp->beep();
         sg->ignore=true;
-        writeConsole(i18n("Finished download of ") + sg->filename );
+        writeConsole(i18n("Finished download of ") + sg->filename
+            + i18n(" from ") + sg->user );
 
         // delete
         downloadpanel->removeDownloadItem(sg);
@@ -1048,7 +1102,7 @@ void Knapster::updateUploadList()
       if(sg->status==NapsterUpload::DL_FINISHED) {
         //if((PropertiesDlg::readPrefs()).beep) kapp->beep();
         sg->ignore=true;
-        writeConsole(i18n("Finished upload of ") + sg->filename );
+        writeConsole(i18n("Finished upload of ") + sg->filename + i18n(" to ") + sg->user);
 
         // delete
         uploadpanel->removeUploadItem(sg);
