@@ -432,6 +432,12 @@ string NapsterConnection::getIPAddressString() const
   return(s);
 }
 
+int NapsterConnection::getIPPort() const
+{
+  return ntohl(_sockaddr.sin_port);
+}
+
+
 // read the comms port -> ret -1 on error and -2 on timeout
 // otherwise ret num of chars read
 int NapsterConnection::readComm(char *xbuffer,int size)
@@ -446,7 +452,7 @@ int NapsterConnection::readComm(char *xbuffer,int size)
   }
 
   // using recv not read since we want full records not
-  // just whatever we acn get??
+  // just whatever we can get??
   s=recv(_napster,xbuffer,size,0);
 
   return(s);
@@ -493,7 +499,7 @@ NAPBLOCKPTR NapsterConnection::readBlock()
   ptr->size=NAP_TO_SHORT(ptr->size); // make sure its in the right endian
   ptr->type=NAP_TO_SHORT(ptr->type);
 
-  if(ptr->size < 0) {
+  if((short int)ptr->size < 0) {
     //cout<<"size error\n";
     ptr->type=NAP_ERROR;
     _lasterror=NAP_BAD_RECV_DATA;
@@ -617,6 +623,7 @@ NapsterDownload *NapsterConnection::startDownload(long ip,int port,const char *f
 bool NapsterConnection::setupListener(int _port)
 {
    struct sockaddr_in server;
+   int len=1;
 
    if(_local==-1) {
      _local = socket(AF_INET, SOCK_STREAM, 0);
@@ -632,6 +639,8 @@ bool NapsterConnection::setupListener(int _port)
      server.sin_addr.s_addr = htonl(INADDR_ANY);
      server.sin_port = htons(_port);
 
+     setsockopt(_local, SOL_SOCKET, SO_REUSEADDR, &len, sizeof(len));
+
      if (bind(_local, (struct sockaddr *)&server, sizeof(server)) < 0) {
 #ifdef DEBUG_1
       cerr<< "bind error in connection listener\n"<<flush;
@@ -818,7 +827,9 @@ bool NapsterConnection::share(const SongInfo *s)
     + " " + QString().setNum(s->seconds);
 //  str=str.stripWhiteSpace();
 
+#ifdef DEBUG_1
   cerr<<"sending: "<<str<<endl<<flush;
+#endif
 
   return writeBlock(NAP_ADDTOSONGLIST_REQ,str,str.length())!=-1;
 }
