@@ -43,9 +43,9 @@ PropertiesDlg::PropertiesDlg(QWidget *parent)
 {
   setCaption(i18n("Properties"));
   // we want all 3 buttons
-  setOkButton();
-  setCancelButton();
-  setApplyButton();
+  setOkButton(i18n("OK"));
+  setCancelButton(i18n("Cancel"));
+  setApplyButton(i18n("Apply"));
 
   // setup the tabs
   setupTabs();
@@ -64,17 +64,20 @@ PropertiesDlg::~PropertiesDlg()
 
 void PropertiesDlg::setupTabs()
 {
+  int maxw_sz;
 
   // tab1 - user -------------------
   const int rows1 =6;
   const int cols1 =3;
 
+
   QWidget *frame=new QWidget(this);
 
   QGridLayout *grid=new QGridLayout(frame,rows1,cols1,5,5);
 
   QLabel *l1=new QLabel(i18n("Username "),frame);
   grid->addWidget(l1,0,0);
+  maxw_sz =  l1->sizeHint().width();
 
   username = new QLineEdit(frame, "username" );
   username->setMaxLength(30);          // is there a real limit ?????
@@ -82,6 +85,7 @@ void PropertiesDlg::setupTabs()
 
   QLabel *l2=new QLabel(i18n("Password "),frame);
   grid->addWidget(l2,1,0);
+  maxw_sz =  maxw_sz > l2->sizeHint().width() ? maxw_sz : l2->sizeHint().width();
 
   password = new QLineEdit(frame, "password" );
   password->setMaxLength(30);
@@ -92,6 +96,7 @@ void PropertiesDlg::setupTabs()
 
   QLabel *l3=new QLabel(i18n("Email "),frame);
   grid->addWidget(l3,2,0);
+  maxw_sz =  maxw_sz > l3->sizeHint().width() ? maxw_sz : l3->sizeHint().width();
 
   email = new QLineEdit(frame, "email" );
   email->setMaxLength(46);
@@ -100,11 +105,11 @@ void PropertiesDlg::setupTabs()
   // retry connect until succesfull
   // toggle ????????
 
-  QSize sz(l2->sizeHint().width(),username->sizeHint().height());
+//  QSize sz(maxw_sz,username->sizeHint().height());
 
-  l1->setMaximumWidth(sz.width());
-  l2->setMaximumWidth(sz.width());
-  l3->setMaximumWidth(sz.width());
+  l1->setMaximumWidth(maxw_sz);
+  l2->setMaximumWidth(maxw_sz);
+  l3->setMaximumWidth(maxw_sz);
 
   newuser= new QCheckBox(i18n("Logon as new user"),frame,"newuser");
   grid->addMultiCellWidget(newuser,3,3,0,2);
@@ -119,6 +124,7 @@ void PropertiesDlg::setupTabs()
 
   l1=new QLabel(i18n("Napster Server "),frame);
   grid->addWidget(l1,0,0);
+  maxw_sz =  l1->sizeHint().width();
 
   serveraddr = new QLineEdit(frame, "serveraddr" );
   serveraddr->setMaxLength(40);
@@ -126,6 +132,7 @@ void PropertiesDlg::setupTabs()
 
   QWidget *l5=new QLabel(i18n("Download port "),frame);
   grid->addWidget(l5,1,0);
+  maxw_sz =  maxw_sz > l5->sizeHint().width() ? maxw_sz : l5->sizeHint().width();
 
   port = new QLineEdit(frame, "port" );
   port->setMaxLength(5);          // is there a real limit ?????
@@ -133,6 +140,7 @@ void PropertiesDlg::setupTabs()
 
   QWidget *l4=new QLabel(i18n("Connection speed "),frame);
   grid->addWidget(l4,2,0);
+  maxw_sz =  maxw_sz > l4->sizeHint().width() ? maxw_sz : l4->sizeHint().width();
 
   speed=new QComboBox(false,frame,"speed");
   speed->insertItem(i18n("Unknown"));
@@ -148,13 +156,14 @@ void PropertiesDlg::setupTabs()
   speed->insertItem(i18n("T3+"));
   grid->addWidget(speed,2,1);
 
-  int w1 = l1->sizeHint().width();
-  int w5 = l5->sizeHint().width();
-  int w4 = l4->sizeHint().width();
-  int width = (w1 > w5) ? w1 : w5;
-  width = (width > w4) ? width : w4;
-  sz.setWidth(width);
-  sz.setHeight(speed->sizeHint().height());
+//  int w1 = l1->sizeHint().width();
+//  int w5 = l5->sizeHint().width();
+//  int w4 = l4->sizeHint().width();
+//  int width = (w1 > w5) ? w1 : w5;
+//  width = (width > w4) ? width : w4;
+//  sz.setWidth(width);
+//  sz.setHeight(speed->sizeHint().height());
+  QSize sz(maxw_sz,speed->sizeHint().height());
 
   port->setMaximumSize(sz);
   l5->setMaximumSize(sz);
@@ -178,6 +187,7 @@ void PropertiesDlg::setupTabs()
 
   l1=new QLabel(i18n("Download directory "),frame);
   grid->addWidget(l1,0,0);
+  maxw_sz =  l1->sizeHint().width();
 
   downloaddir = new QLineEdit(frame, "dload" );
   grid->addMultiCellWidget(downloaddir,0,0,1,2);
@@ -189,6 +199,7 @@ void PropertiesDlg::setupTabs()
 
   l2=new QLabel(i18n("Max download connections "),frame);
   grid->addWidget(l2,1,0);
+  maxw_sz =  maxw_sz > l2->sizeHint().width() ? maxw_sz : l2->sizeHint().width();
 
   maxdownloads = new QLineEdit(frame, "downloads" );
   maxdownloads->setMaxLength(3);
@@ -200,18 +211,19 @@ void PropertiesDlg::setupTabs()
 
   l4=new QLabel(i18n("Max upload connections "),frame);
   grid->addWidget(l4,3,0);
+  maxw_sz =  maxw_sz > l4->sizeHint().width() ? maxw_sz : l4->sizeHint().width();
 
   maxuploads = new QLineEdit(frame, "uploads" );
   maxuploads->setMaxLength(3); // up to 999 should be enough ???? comments anyone ??????
   grid->addWidget(maxuploads,3,1);
 
-  w1 = l1->sizeHint().width();
-  int w2 = l2->sizeHint().width();
-  w4 = l4->sizeHint().width();
-  width = (w1 > w2) ? w1 : w2;
-  width = (width > w4) ? width : w4;
+//  w1 = l1->sizeHint().width();
+//  int w2 = l2->sizeHint().width();
+//  w4 = l4->sizeHint().width();
+//  width = (w1 > w2) ? w1 : w2;
+//  width = (width > w4) ? width : w4;
 
-  QSize sz2(width,downloadbutton->sizeHint().height());
+  QSize sz2(maxw_sz,downloadbutton->sizeHint().height());
 
   l1->setMaximumSize(sz2);
   l2->setMaximumSize(sz2);
@@ -267,6 +279,7 @@ void PropertiesDlg::setupTabs()
 
   l1=new QLabel(i18n("path "),frame);
   grid->addWidget(l1,4,0);
+  maxw_sz =  l1->sizeHint().width();
 
   addpathdir = new QLineEdit(frame, "lib_path" );
   grid->addMultiCellWidget(addpathdir,4,4,1,3);
@@ -277,7 +290,9 @@ void PropertiesDlg::setupTabs()
   grid->addWidget(pathbutton,4,4);
 
   l2=new QLabel(i18n("shared "),frame);
-  l2->setMaximumWidth(l2->sizeHint().width());
+  maxw_sz =  maxw_sz > l2->sizeHint().width() ? maxw_sz : l2->sizeHint().width();
+
+  l2->setMaximumWidth(maxw_sz);
   grid->addWidget(l2,5,0);
 
   shared=new QComboBox(false,frame,"shared");
@@ -294,18 +309,29 @@ void PropertiesDlg::setupTabs()
   shareddepth = new QLineEdit(frame, "dirdepth" );
   shareddepth->setMaxLength(1); // up to 9 enough
   grid->addWidget(shareddepth,5,3);
+//  maxw_sz =  shareddepth->sizeHint().width();
   shareddepth->setMaximumWidth(shareddepth->sizeHint().width());
 
   QPushButton *addbutton = new QPushButton(i18n("Insert"),frame,"insert");
   grid->addWidget(addbutton,6,3);
   connect(addbutton,SIGNAL(clicked()),this,SLOT(addPath()));
-  addbutton->setMaximumSize(addbutton->sizeHint());
+  maxw_sz =  addbutton->sizeHint().width();
+
 
   QPushButton *delbutton = new QPushButton(i18n("Delete"),frame,"delete");
   grid->addWidget(delbutton,6,4);
-  delbutton->setMaximumSize(addbutton->sizeHint());
+  maxw_sz =  maxw_sz > delbutton->sizeHint().width() ?
+        maxw_sz : delbutton->sizeHint().width();
   connect(delbutton,SIGNAL(clicked()),this,SLOT(delPath()));
 
+
+  maxw_sz =  maxw_sz > pathbutton->sizeHint().width() ?
+     maxw_sz : pathbutton->sizeHint().width();
+
+  addbutton->setMaximumWidth(maxw_sz);
+  addbutton->setMaximumSize(addbutton->sizeHint());
+  delbutton->setMaximumSize(addbutton->sizeHint());
+
   addTab(frame,i18n("Library paths"));
 }
 
@@ -572,7 +598,9 @@ Preferences PropertiesDlg::readPrefs()
    p.email=p.email.stripWhiteSpace();
 
    // server
-   p.serveraddr=kapp->getConfig()->readEntry("serveraddr","208.184.216.223");
+   p.serveraddr=kapp->getConfig()->readEntry("serveraddr","server.napster.com");
+   //"208.184.216.223");
+
    p.serveraddr=p.serveraddr.stripWhiteSpace();
    if(p.serveraddr.length()==0) p.serveraddr="208.184.216.223";
 
